C
C     Subroutines to initialize the parameters describing the geometric
C     transformation between a position on the CCD plane and one on the
C     instrument focal plane.
C
C     The transformation description originated in the COSMOS code,
C     written for IMACS multi-slit data.  The "SITE.dewdef" and
C     "SCdirect_N.dewoff" files are a legacy of this software, as well
C     as readcdf() and readcof().  [The old setcdf() and setcof(), now
C     bundled into initdewar(), replace readcdf() and readcof() and
C     obviate the need for extra data files.]
C
C     "dewdef.f" sets up a module (formerly a common block) for use by
C     these subroutines and the calling program.
C
CCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     
C     Routine that bundles setcdf() and setcof() calls into one.
C
      subroutine initdewar()
c
      use dewdef
C
C     Sets variables to contents of SITE.dewdef file.
c
c  Long camera scale??
c      dscale = 1.0
      xchip = xchip -1
      ychip = ychip -1
      do i = 1,nchip
         dtheta(i) = dtheta(i) / 57.2958
      end do
c
C     Set variables to contents of SCdirect_N.dewoff file.
C     
      dcth = 179.961
      dscale = 1.00349
      dcx = -0.716
      dcy = -0.181
c from SCdirect_NS.dewoff
c      dcth = 89.901
c      dscale = 1.00323
c      dcx = -0.904
c      dcy = -0.107

      dcth = dcth / 57.2958

      return
      end

CCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C     Read SITE.dewdef file and input into common block variables.  Note
C     that because Readcdf() sets dscale=1.0 and Readcof() reads the
C     value from a file, you must call readcdf before readcof.  This is
C     a bug.
c
c      subroutine readcdf(dirname)
c
c      include "dewdef.h"
c
c      character cline*80,dirname*(*),fname*100
c
c      ilen = index(dirname,' ')
c      fname = dirname(1:ilen-1) // '/SITE.dewdef.edit'
c      open(2,file=fname,status='old')
c
c     Reset dscale.  Reason for this ???
c      dscale = 1.0
c     Get #of chips, chip sizes, pixels/mm.
c      call readline1(2,cline,ierr)
c      read (cline,*) nchip, xchip, ychip, scale
c     Convert to 0-based.  Keep this in but beware ...
c      xchip = xchip-1
c      ychip = ychip-1
c      do i=1,nchip
c         call readline1(2,cline,ierr)
c         read(cline,*) xmin(i),xmax(i),ymin(i),ymax(i)
c         call readline1(2,cline,ierr)
c         read(cline,*) xz(i),sxz(i),yz(i),syz(i)
c         call readline1(2,cline,ierr)
c         read(cline,*) dtheta(i)
c         dtheta(i) = dtheta(i) / 57.2958
c         call readline1(2,cline,ierr)
c         read(cline,*) xx0(i),yy0(i)
c      end do
c      call readline1(2,cline,ierr)
c      read(cline,*) nsl_n,sl_coef(1),sl_coef(2),
c     +     sl_coef(3),sl_coef(4)
c      call readline1(2,cline,ierr)
c      read(cline,*) nsts1_n,sts1_coef(1),sts1_coef(2),
c     +     sts1_coef(3),sts1_coef(4)
c      call readline1(2,cline,ierr)
c      read(cline,*) nstt1_n,stt1_coef(1),stt1_coef(2),
c     +     stt1_coef(3),stt1_coef(4)
c      call readline1(2,cline,ierr)
c      read(cline,*) nsts2_n,sts2_coef(1),sts2_coef(2),
c     +     sts2_coef(3),sts2_coef(4)
c      call readline1(2,cline,ierr)
c      read(cline,*) nstt2_n,stt2_coef(1),stt2_coef(2),
c     +     stt2_coef(3),stt2_coef(4)
c      call readline1(2,cline,ierr)
c      read(cline,*) nsrs1_n,srs1_coef(1),srs1_coef(2),
c     +     srs1_coef(3),srs1_coef(4)
c      call readline1(2,cline,ierr)
c      read(cline,*) nsrt1_n,srt1_coef(1),srt1_coef(2),
c     +     srt1_coef(3),srt1_coef(4)
c      call readline1(2,cline,ierr)
c      read(cline,*) nsrs2_n,srs2_coef(1),srs2_coef(2),
c     +     srs2_coef(3),srs2_coef(4)
c      call readline1(2,cline,ierr)
c      read(cline,*) nsrt2_n,srt2_coef(1),srt2_coef(2),
c     +     srt2_coef(3),srt2_coef(4)
c      call readline1(2,cline,ierr)
c      read(cline,*) nsrz_n,srz_coef(1),srz_coef(2),
c     +     srz_coef(3),srz_coef(4)
c      close(2)
c      return
c      end
c
CCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C     Read SCdirect_N.dewoff file and input into common block variables.
C     
c      subroutine readcof(dirname)
c
c      include "dewdef.h"
c
c      parameter (NUMCHIPS=8)
c      character cline*80,dirname*(*),fname*100
c
c      ilen = index(dirname,' ')
c      fname = dirname(1:ilen-1) // '/SCdirect_N.dewoff'
cc      fname = dirname(1:ilen-1) // '/SCdirect_NS.dewoff'
c      open(2,file=fname,status='old')
c
c      call readline1(2,cline,ierr)
c      read(cline,*) dcth,dscale,dcx,dcy
c      dcth = dcth / 57.2958
c
cc  Long camera scale??
c
c      dscale = 1.0
c      xchip = xchip -1
c      ychip = ychip -1
c      do i = 1,nchip
c         dtheta(i) = dtheta(i) / 57.2958
c      end do
c      return
c      end
c      
c
CCCCCCCCCCCCCCCCCCCCCCCCCCCC
C
C     Utility routine to skip comment lines
C
c      subroutine readline1(iunit,cline,ierr)
c      integer iunit
c      character cline*(*)
c      
c 10   continue
c      read(iunit,'(a)',err=30,end=40) cline
c      if (cline(1:1) .eq. '#') go to 10
c      ierr=0
c      return
c 30   ierr=1
c      return
c 40   ierr=2
c      return
c      end
